<?php

/**
 * @file
 * Contains theme functions.
 */

/**
 * Preprocess callback for theme_fluxservice_add_account_by_service().
 */
function template_preprocess_fluxservice_add_account_by_service(&$variables) {
  $variables['attributes'] = $variables['element']['#attributes'];
  $variables['item_attributes'] = isset($variables['element']['#item_attributes']) ? $variables['element']['#item_attributes'] : array();
  $variables['links'] = $variables['element']['#links'];

  // Care about the icon.
  $info = fluservice_get_service_icon_info($variables['element']['#service']);

  // Prepend the right base path.
  if (isset($info['icon'])) {
    $base_path = isset($info['icon path']) ? $info['icon path'] : drupal_get_path('module', $info['module']);
    $info['icon'] = $base_path . '/' . $info['icon'];
  }
  $variables['icon'] = theme('fluxservice_icon', $info);
}

/**
 * Theme function for adding an account by service plugin.
 */
function theme_fluxservice_add_account_by_service(&$variables) {
  $links = $variables['links'];
  $output = '';
  if (!empty($links)) {
    $output = '<ul' . drupal_attributes($variables['attributes']) . '>';
    foreach ($links as $item) {
      $output .= '<li>';
      $options = array('html' => TRUE) + (isset($item['options']) ? $item['options'] : array());
      $output .= l($variables['icon'] . $item['title'], $item['href'], $options);
      if (isset($item['description'])) {
        $output .= '<div class="description">' . filter_xss_admin($item['description']) . '</div>';
      }
      $output .= '</li>';
    }
    $output .= '</ul>';
  }
  return $output;
}

/**
 * Preprocess callback for theme_fluxservice_icon().
 */
function template_preprocess_fluxservice_icon(&$variables) {
  $variables['background_color'] = isset($variables['icon background color']) ? $variables['icon background color'] : '#ddd';
  // Add background via inline CSS.
  $variables['icon_wrapper_attributes']['style'][] = "background-color: {$variables['background_color']};";
  $variables['icon_wrapper_attributes']['class'][] = 'fluxservice-icon';
  $variables['icon_attributes'] = array();

  if (isset($variables['icon'])) {
    $variables['icon_attributes']['class'][] = 'fluxservice-icon-file';
    $variables['icon'] = theme('image', array('path' => $variables['icon']));
  }
  else {
    // Add a default class as fallback for bad modules not providing an icon.
    if (!isset($variables['icon font class'])) {
      $variables['icon font class'] = 'icon-star';
    }
    $variables['icon_attributes']['class'][] = $variables['icon font class'];
    $variables['icon_attributes']['class'][] = 'fluxservice-icon-font';
  }
}

/**
 * Theme function for theming a service icon.
 */
function theme_fluxservice_icon(&$variables) {
  $output = '<div' . drupal_attributes($variables['icon_wrapper_attributes']) . '><span' . drupal_attributes($variables['icon_attributes']) . '>';
  $output .= $variables['icon'];
  $output .= '</span></div>';
  return $output;
}
